﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Drawing;

namespace howto_blended_composite
{
    public static class Extensions
    {
        public static void DrawRectangle(this Graphics gr, Pen pen, RectangleF rect)
        {
            gr.DrawRectangle(pen, rect.X, rect.Y, rect.Width, rect.Height);
        }

        public static void DrawBox(this Graphics gr,
            Brush brush, Pen pen, PointF center, float radius)
        {
            RectangleF rect = new RectangleF(
                center.X - radius,
                center.Y - radius,
                2 * radius, 2 * radius);
            gr.FillRectangle(brush, rect);
            gr.DrawRectangle(pen, rect);
        }

        // Return the image scaled.
        public static Bitmap ScaleImage(this Bitmap bm, float scale)
        {
            if (bm == null) return null;

            int scaled_width = (int)(bm.Width * scale);
            int scaled_height = (int)(bm.Height * scale);
            Bitmap result = new Bitmap(scaled_width, scaled_height);
            using (Graphics gr = Graphics.FromImage(result))
            {
                Point[] dest_points =
                {
                    new Point(0, 0),
                    new Point(scaled_width - 1, 0),
                    new Point(0, scaled_height - 1),
                };
                Rectangle src_rect = new Rectangle(
                    0, 0,
                    bm.Width - 1,
                    bm.Height - 1);
                gr.DrawImage(bm, dest_points, src_rect, GraphicsUnit.Pixel);
            }
            return result;
        }
    }
}
